@@ -86,14 +86,53 @@ def acknowledge(host_name, service_description=None, sticky=1, notify=1, persist
                                                       )
 
 
-def downtime(host_name, service_description=None, start_time=None, end_time=None, fixed=1, trigger_id=0, duration=7200, author='adagios', comment='Downtime scheduled by adagios', all_services_on_host=False):
+def downtime(host_name=None, service_description=None, start_time=None, end_time=None, fixed=1, trigger_id=0, duration=7200, author='adagios', comment='Downtime scheduled by adagios', all_services_on_host=False, hostgroup_name=None):
     """ Schedule downtime for a host or a service """
     if fixed in (1, '1') and start_time in (None, ''):
         start_time = time.time()
     if fixed in (1, '1') and end_time in (None, ''):
         end_time = int(start_time) + int(duration)
-    if all_services_on_host == True:
-        return pynag.Control.Command.schedule_host_svc_downtime(
+    if all_services_on_host == 'false':
+        all_services_on_host = False
+    elif all_services_on_host == 'true':
+        all_services_on_host = True
+
+    # Check if we are supposed to schedule downtime for a whole hostgroup:
+    if hostgroup_name:
+        result1 = pynag.Control.Command.schedule_hostgroup_host_downtime(
+            hostgroup_name=hostgroup_name,
+            start_time=start_time,
+            end_time=end_time,
+            fixed=fixed,
+            trigger_id=trigger_id,
+            duration=duration,
+            author=author,
+            comment=comment,
+        ),
+        result2 = pynag.Control.Command.schedule_hostgroup_svc_downtime(
+            hostgroup_name=hostgroup_name,
+            start_time=start_time,
+            end_time=end_time,
+            fixed=fixed,
+            trigger_id=trigger_id,
+            duration=duration,
+            author=author,
+            comment=comment,
+        )
+        return result1, result2
+    # Check if we are recursively scheduling downtime for host and all its services:
+    elif all_services_on_host:
+        result1 = pynag.Control.Command.schedule_host_svc_downtime(
+            host_name=host_name,
+            start_time=start_time,
+            end_time=end_time,
+            fixed=fixed,
+            trigger_id=trigger_id,
+            duration=duration,
+            author=author,
+            comment=comment,
+        ),
+        result2 = pynag.Control.Command.schedule_host_downtime(
             host_name=host_name,
             start_time=start_time,
             end_time=end_time,
@@ -103,6 +142,8 @@ def downtime(host_name, service_description=None, start_time=None, end_time=None
             author=author,
             comment=comment,
         )
+        return result1, result2
+    # Otherwise, if this is a host
     elif service_description in (None, '', u'', '_HOST_'):
         return pynag.Control.Command.schedule_host_downtime(
             host_name=host_name,
@@ -114,20 +155,22 @@ def downtime(host_name, service_description=None, start_time=None, end_time=None
             author=author,
             comment=comment,
         )
+    # otherwise it must be a service:
     else:
-        return pynag.Control.Command.schedule_svc_downtime(host_name=host_name,
-                                                           service_description=service_description,
-                                                           start_time=start_time,
-                                                           end_time=end_time,
-                                                           fixed=fixed,
-                                                           trigger_id=trigger_id,
-                                                           duration=duration,
-                                                           author=author,
-                                                           comment=comment,
-                                                           )
+        return pynag.Control.Command.schedule_svc_downtime(
+            host_name=host_name,
+            service_description=service_description,
+            start_time=start_time,
+            end_time=end_time,
+            fixed=fixed,
+            trigger_id=trigger_id,
+            duration=duration,
+            author=author,
+            comment=comment,
+        )
 
 
-def reschedule(host_name, service_description, check_time=time.time(), wait=0):
+def reschedule(host_name, service_description=None, check_time=None, wait=0):
     """ Reschedule a check of this service/host
 
     Arguments:
@@ -138,22 +181,30 @@ def reschedule(host_name, service_description, check_time=time.time(), wait=0):
     """
     if check_time is None or check_time is '':
         check_time = time.time()
-    if service_description in (None, '', u'', '_HOST_'):
+    if service_description in (None, '', u'', '_HOST_', 'undefined'):
         service_description = ""
         pynag.Control.Command.schedule_forced_host_check(
             host_name=host_name, check_time=check_time)
+        if wait == "1":
+            livestatus = pynag.Parsers.mk_livestatus()
+            livestatus.query("GET hosts",
+                             "WaitObject: %s " % host_name,
+                             "WaitCondition: last_check > %s" % check_time,
+                             "WaitTrigger: check",
+                             "Filter: host_name = %s" % host_name,
+                             )
     else:
         pynag.Control.Command.schedule_forced_svc_check(
             host_name=host_name, service_description=service_description, check_time=check_time)
-    if wait == "1":
-        livestatus = pynag.Parsers.mk_livestatus()
-        livestatus.query("GET services",
-                         "WaitObject: %s %s" % (
-                             host_name, service_description),
-                         "WaitCondition: last_check > %s" % check_time,
-                         "WaitTrigger: check",
-                         "Filter: host_name = %s" % host_name,
-                         )
+        if wait == "1":
+            livestatus = pynag.Parsers.mk_livestatus()
+            livestatus.query("GET services",
+                             "WaitObject: %s %s" % (
+                                 host_name, service_description),
+                             "WaitCondition: last_check > %s" % check_time,
+                             "WaitTrigger: check",
+                             "Filter: host_name = %s" % host_name,
+                             )
     return "ok"
 
 
@@ -295,10 +346,10 @@ def delete_downtime(downtime_id, is_service=True):
       is_service  -- If set to True or 1, then this is assumed to be a service downtime, otherwise assume host downtime
     """
     if is_service in (True, 1, '1'):
-        return pynag.Control.Command.del_svc_downtime(downtime_id)
+        pynag.Control.Command.del_svc_downtime(downtime_id)
     else:
-        return pynag.Control.Command.del_host_downtime(downtime_id)
-
+        pynag.Control.Command.del_host_downtime(downtime_id)
+    return "ok"
 
 def top_alert_producers(limit=5, start_time=None, end_time=None):
     """ Return a list of ["host_name",number_of_alerts]
@@ -465,4 +516,41 @@ def get_business_process(process_name=None, process_type=None):
         json['subprocess_count'] = len(i.processes)
         json['process_type'] = i.process_type
         result.append(json)
-    return result
\ No newline at end of file
+    return result
+
+
+def remove_downtime(host_name, service_description=None, downtime_id=None):
+    """ Remove downtime for one specific host or service """
+    downtimes_to_remove = []
+    # If downtime_id is not provided, remove all downtimes of that service or host
+    if downtime_id:
+        downtimes_to_remove.append(downtime_id)
+    else:
+        livestatus = pynag.Parsers.mk_livestatus(nagios_cfg_file=adagios.settings.nagios_config)
+        query_parameters = []
+        query_parameters.append('GET downtimes')
+        query_parameters.append('Filter: host_name = {host_name}'.format(**locals()))
+        if service_description:
+            query_parameters.append('Filter: service_description = {service_description}'.format(**locals()))
+        result = livestatus.query(*query_parameters)
+        for i in result:
+            downtime_id = i['id']
+            downtimes_to_remove.append(downtime_id)
+
+    if service_description:
+        for i in downtimes_to_remove:
+            pynag.Control.Command.del_svc_downtime(downtime_id=i)
+    else:
+        for i in downtimes_to_remove:
+            pynag.Control.Command.del_host_downtime(downtime_id=i)
+    return "ok"
+
+
+def remove_acknowledgement(host_name, service_description=None):
+    """ Remove downtime for one specific host or service """
+    print "running", locals()
+    if not service_description:
+        pynag.Control.Command.remove_host_acknowledgement(host_name=host_name)
+    else:
+        pynag.Control.Command.remove_svc_acknowledgement(host_name=host_name, service_description=service_description)
+    return "ok"
\ No newline at end of file
