@@ -52,17 +52,24 @@ from adagios.views import error_handler, error_page
 
 @error_handler
 def status_parents(request):
+    """ Here for backwards compatibility """
+    return network_parents(request)
+
+@error_handler
+def network_parents(request):
+    """ List of hosts that are network parents """
     c = {}
     c['messages'] = []
     authuser = request.GET.get('contact_name', None)
     livestatus = utils.livestatus(request)
-    all_hosts = livestatus.get_hosts()
+    fields = "name childs state scheduled_downtime_depth acknowledged downtimes services services_with_info".split()
+    hosts = utils.get_hosts(request, 'Filter: childs !=', fields=fields, **request.GET)
     host_dict = {}
-    map(lambda x: host_dict.__setitem__(x['name'], x), all_hosts)
+    map(lambda x: host_dict.__setitem__(x['name'], x), hosts)
     c['hosts'] = []
 
-    for i in all_hosts:
-        if len(i['childs']) > 0:
+    for i in hosts:
+        if i['childs']:
             c['hosts'].append(i)
             ok = 0
             crit = 0
@@ -593,6 +600,12 @@ def status_tiles(request, object_type="host"):
 
 @error_handler
 def status_host(request):
+    """ Here for backwards compatibility """
+    return hosts(request)
+
+
+@error_handler
+def hosts(request):
     c = {}
     c['messages'] = []
     c['errors'] = []
@@ -601,6 +614,19 @@ def status_host(request):
     return render_to_response('status_host.html', c, context_instance=RequestContext(request))
 
 
+@error_handler
+def problems(request):
+    c = {}
+    c['messages'] = []
+    c['errors'] = []
+    search_filter = request.GET.copy()
+    if 'state__isnot' not in search_filter and 'state' not in search_filter:
+        search_filter['state__isnot'] = '0'
+    c['hosts'] = utils.get_hosts(request, **search_filter)
+    c['services'] = utils.get_services(request, **search_filter)
+    return render_to_response('status_problems.html', c, context_instance=RequestContext(request))
+
+
 @error_handler
 def status_boxview(request):
     c = _status(request)
@@ -905,13 +931,7 @@ def dashboard(request):
     #
     c['hosts'] = c['network_problems'] + c['host_problems']
     # Service problems
-    c['service_problems'] = utils.get_services(request,
-                                               state__isnot="0",
-                                               acknowledged="0",
-                                               scheduled_downtime_depth="0",
-                                               host_state="0",
-                                               **request.GET
-                                               )
+    c['service_problems'] = utils.get_services(request, unhandled='', **request.GET)
     # Sort problems by state and last_check as secondary sort field
     c['service_problems'].sort(
         reverse=True, cmp=lambda a, b: cmp(a['last_check'], b['last_check']))
@@ -1107,6 +1127,21 @@ def downtime_list(request):
     c['downtimes'] = grep_dict(downtimes, **args)
     return render_to_response('status_downtimes.html', c, context_instance=RequestContext(request))
 
+@error_handler
+def acknowledgement_list(request):
+    """ Display a list of all comments """
+    c = {}
+    c['messages'] = []
+    c['errors'] = []
+    l = pynag.Parsers.mk_livestatus(
+        nagios_cfg_file=adagios.settings.nagios_config)
+    comments = l.query('GET comments')
+    downtimes = l.query('GET downtimes')
+    args = request.GET.copy()
+    c['comments'] = grep_dict(comments, **args)
+    c['acknowledgements'] = grep_dict(comments, entry_type=4)
+    c['downtimes'] = grep_dict(downtimes, **args)
+    return render_to_response('status_acknowledgements.html', c, context_instance=RequestContext(request))
 
 def grep_dict(array, **kwargs):
     """  Returns all the elements from array that match the keywords in **kwargs
@@ -1146,7 +1181,7 @@ def perfdata(request):
     c['messages'] = []
     c['errors'] = []
     fields = "host_name description perf_data state host_state scheduled_downtime_depth host_scheduled_downtime_depth host_acknowledged acknowledged downtimes host_downtimes".split()
-    perfdata = utils.get_services(None, fields=fields, **request.GET)
+    perfdata = utils.get_services(request, fields=fields, **request.GET)
     for i in perfdata:
         metrics = pynag.Utils.PerfData(i['perf_data']).metrics
         metrics = filter(lambda x: x.is_valid(), metrics)
@@ -1271,14 +1306,17 @@ def perfdata2(request):
     # User can also specify specific metrics to watch, so we extract from
     # querystring as well
     querystring = request.GET.copy()
-    interesting_metrics = querystring.pop('metrics', [''])[0]
+    interesting_metrics = querystring.pop('metrics', [''])[0].strip(',')
     arguments = pynag.Utils.grep_to_livestatus(**querystring)
     services = l.query('GET services', columns, *arguments)
     # If no metrics= was specified on querystring, we take the string
     # from first service in our search result
     if not interesting_metrics and services:
-        perfdata = pynag.Utils.PerfData(services[0]['perf_data'])
-        interesting_metrics = map(lambda x: x.label, perfdata.metrics)
+        metric_set = set()
+        for i in services:
+            perfdata = pynag.Utils.PerfData(i.get('perf_data',''))
+            map(lambda x: metric_set.add(x.label), perfdata.metrics)
+        interesting_metrics = sorted(list(metric_set))
     else:
         interesting_metrics = interesting_metrics.split(',')
 
